@@ -4,9 +4,6 @@ from django.template.defaultfilters import slugify
 
 from social_auth.utils import setting
 from social_auth.models import UserSocialAuth
-from social_auth.backends import USERNAME
-from social_auth.signals import socialauth_registered, \
-                                pre_update
 
 
 def get_username(details, user=None,
@@ -24,8 +21,8 @@ def get_username(details, user=None,
 
     if email_as_username and details.get('email'):
         username = details['email']
-    elif details.get(USERNAME):
-        username = unicode(details[USERNAME])
+    elif details.get('username'):
+        username = unicode(details['username'])
     else:
         username = uuid4().get_hex()
 
@@ -55,9 +52,17 @@ def create_user(backend, details, response, uid, username, user=None, *args,
     if not username:
         return None
 
+    # Avoid hitting field max length
+    email = details.get('email')
+    original_email = None
+    if email and UserSocialAuth.email_max_length() < len(email):
+        original_email = email
+        email = ''
+
     return {
         'user': UserSocialAuth.create_user(username=username,
-                                           email=details.get('email')),
+                                           email=email),
+        'original_email': original_email,
         'is_new': True
     }
 
@@ -73,33 +78,12 @@ def update_user_details(backend, details, response, user=None, is_new=False,
     for name, value in details.iteritems():
         # do not update username, it was already generated
         # do not update configured fields if user already existed
-        if name in (USERNAME, 'id', 'pk') or (not is_new and
+        if name in ('username', 'id', 'pk') or (not is_new and
            name in setting('SOCIAL_AUTH_PROTECTED_USER_FIELDS', [])):
             continue
         if value and value != getattr(user, name, None):
             setattr(user, name, value)
             changed = True
 
-    # Fire a pre-update signal sending current backend instance,
-    # user instance (created or retrieved from database), service
-    # response and processed details.
-    #
-    # Also fire socialauth_registered signal for newly registered
-    # users.
-    #
-    # Signal handlers must return True or False to signal instance
-    # changes. Send method returns a list of tuples with receiver
-    # and it's response.
-    signal_response = lambda (receiver, response): response
-    signal_kwargs = {'sender': backend.__class__, 'user': user,
-                     'response': response, 'details': details}
-
-    changed |= any(filter(signal_response, pre_update.send(**signal_kwargs)))
-
-    # Fire socialauth_registered signal on new user registration
-    if is_new:
-        changed |= any(filter(signal_response,
-                              socialauth_registered.send(**signal_kwargs)))
-
     if changed:
         user.save()
