@@ -13,7 +13,7 @@ class for details on how to extend it.
 """
 from django.utils import simplejson
 
-from social_auth.backends import ConsumerBasedOAuth, OAuthBackend, USERNAME
+from social_auth.backends import ConsumerBasedOAuth, OAuthBackend
 from social_auth.exceptions import AuthCanceled
 
 
@@ -40,7 +40,7 @@ class TwitterBackend(OAuthBackend):
         except:
             first_name = response['name']
             last_name = ''
-        return {USERNAME: response['screen_name'],
+        return {'username': response['screen_name'],
                 'email': '',  # not supplied
                 'fullname': response['name'],
                 'first_name': first_name,
